@@ -25,6 +25,7 @@ import six
 from six.moves.urllib import parse
 from . import exit_codes, progress, utils, exceptions, pkg_info
 from .exceptions import InvalidFileError
+from requests import status_codes
 
 try:
     from concurrent.futures import ThreadPoolExecutor, Future
@@ -33,13 +34,13 @@ except ImportError:
 
 
 class ResponseError(Exception):
-    def __init__(self, res, errorType):
+    def __init__(self, res, errorType, errorMessage=None):
         if type(res) is int:
             code = res
         else:
             code = res.status_code
             self.res = res
-        Exception.__init__(self, errorType + " error: %i" % code)
+        Exception.__init__(self, errorType + " error: %i, message: %s" % (code, errorMessage))
         self.status_code = code
 
     def get_resource_body(self):
@@ -88,7 +89,7 @@ class OCSResponseError(ResponseError):
 
 class HTTPResponseError(ResponseError):
     def __init__(self, res):
-        ResponseError.__init__(self, res, "HTTP")
+        ResponseError.__init__(self, res, "HTTP", status_codes._codes.get(res.status_code, (None,))[0])
 
 
 class ShareInfo(object):
@@ -788,7 +789,7 @@ class Client(object):
                     return res
             except (HTTPResponseError, IOError) as e:
                 retry += 1
-                if retry >= self.put_max_retry:
+                if retry >= self.put_max_retry or (hasattr(e, "status_code") and e.status_code == 507):
                     raise e
                 else:
                     print(" Error occurred: %s.\n Trying to upload the file again. Wait for 5 seconds..." % e)
