@@ -476,9 +476,19 @@ def cmd_mkdir(args):
     destination = normalize_oc_path(args.pop())
     cfg = Config()
     client = get_client()
-    if client.exists(destination):
-        raise ParameterError("Remote path %s already exists. Give it a new name" % format_oc_path_output(convert(destination)))
-    client.mkdir(destination)
+    if cfg.parents:
+        paths = destination.split("/")
+        parent = "/"
+        for path in paths:
+            if len(path) != 0:
+                parent = os.path.join(parent, path)
+                if not client.exists(parent):
+                    client.mkdir(parent)
+
+    else:
+        if client.exists(destination):
+            raise ParameterError("Remote path %s already exists. Give it a new name" % format_oc_path_output(convert(destination)))
+        client.mkdir(destination)
     return EX_OK
 
 
@@ -797,6 +807,7 @@ def cmd():
     optparser.add_option(      "--chunk-size-mb", dest="chunk_size_mb", type="int", action="store", metavar="SIZE", help="Size of each chunk of an upload. Files bigger than SIZE are automatically uploaded as chunk, smaller files are uploaded using the traditional method. SIZE is in Mega-Bytes, default chunk size is 15MB, minimum allowed chunk size is 5MB, maximum is 5GB.")
     optparser.add_option(      "--chunked", dest="chunked", action="store_true", help="Enable chunk upload on files bigger than --chunk-size-mb")
     optparser.add_option(      "--cache_valid_hour", dest="cache_valid_hour", type="int", action="store", metavar="HOUR", help="Cache file valid hour for chunk upload, default hour is 8")
+    optparser.add_option("-p", "--parents", dest="parents", action="store_true", help="No error if existing, make parent directories as needed")
     optparser.add_option("-r", "--recursive", dest="recursive", action="store_true", help="Recursive removal.")
     optparser.add_option("-v", "--verbose", dest="verbosity", action="store_const", const=logging.INFO,
                          help="Enable verbose output.")
