@@ -8,11 +8,11 @@ test_id = int(time.time())
 
 Config = {
     # Change this to your ownCloud's URL
-    'owncloud_url': 'https://pan.ge.cn/',
+    'owncloud_url': 'https://dataccess.getui.com/',
     # ownCloud login
     'owncloud_login': 'yebk',
     # ownCloud password
-    'owncloud_password': 'yll,0705',
+    'owncloud_password': 'Q6g#nEAssXGMyGJSTen^4qkn54efU',
     # test user whom we want to share a file
     'owncloud_share2user': 'share',
     # test group, uses to add owncloud_share2user to it etc
